@@ -29,7 +29,7 @@ class YSL:
 
 
 class StreamLiker(YSL):
-    def __init__(self, channels_path, email, passwd):
+    def __init__(self, channels_path):
         super(StreamLiker, self).__init__(channels_path)
         self.start_time = None
         self.time_started = None
@@ -37,39 +37,33 @@ class StreamLiker(YSL):
         self.time_ended = None
         self.check_streamers_time = None
 
-        self.active_streams = []
         self.currently_streaming = {}
-        self.streams_liked = {}
-        self.streams_liked_id = []
-        self.video_ids = []
         self.stream_data = OrderedDict()
         self.number_of_active_streams = 0
         self.number_of_to_be_liked_streams = 0
         self.date = None
 
-        self.email = email
-        self.passwd = passwd
-
+        self.like = False
         self.driver = None
         self.options = FirefoxOptions()
 
-        self.version = "1.5.1"
+        self.version = "1.5.2"
 
     def clear_data(self):
         self.start_time = None
         self.time_started = None
         self.total_time_elapsed = 0
         self.time_ended = None
+        self.check_streamers_time = None
 
         self.currently_streaming = {}
-        self.streams_liked = {}
-        self.streams_liked_id = []
-        self.video_ids = []
         self.stream_data = OrderedDict()
         self.number_of_active_streams = 0
         self.number_of_to_be_liked_streams = 0
         self.date = None
 
+        self.like = False
+
     def get_start_time(self):
         self.start_time = time.time()
         self.time_started = time.strftime("%H:%M:%S", time.localtime())
@@ -77,18 +71,20 @@ class StreamLiker(YSL):
 
     def is_streaming(self):
         s_time = time.time()
-        ##### Status Code
+
         print('Current Status: Checking for streams...')
         print('-'*30)
 
         for name in self.channels.keys():
-            print(name, end=" - ")
             channel_url = 'https://www.youtube.com/channel/' + self.channels[name]
             response = requests.get(channel_url).text
             stream_active = '{"text":" watching"}' in response
+
+            print(name, end=" - ")
             print("is ", end="")
             if stream_active:
-                self.currently_streaming[name] = channel_url
+                v_index = response.find("videoRenderer")
+                self.currently_streaming[name] = response[v_index+27:v_index+38]
                 self.number_of_active_streams += 1
                 print("currently streaming.")
             else:
@@ -102,26 +98,12 @@ class StreamLiker(YSL):
 
     def like_videos(self):
 
-        if self.number_of_active_streams == 0:
-            print("There are no active streams as of the moment.")
-        elif self.number_of_active_streams > 0:
+        if self.like:
             print("Current status: Liking videos...")
             print('-' * 30)
-            for name, channel_link in self.currently_streaming.items():
+            for name, video_id in self.currently_streaming.items():
                 is_liked = False
-                like_button = None
-                link = None
-                self.driver.get(channel_link + '/videos')
-
-                try:
-                    video_url = WebDriverWait(self.driver, 10).until(
-                        EC.presence_of_element_located((By.XPATH, '//*[@id="thumbnail"]'))
-                    )
-                    link = video_url.get_attribute('href')
-                except:
-                    assert False, "LinkFetchError: Cannot find XPATH."
-
-                self.active_streams.append(link[32:])
+                link = "https://www.youtube.com/watch?v=" + video_id
                 self.driver.get(link)
 
                 try:
@@ -138,13 +120,12 @@ class StreamLiker(YSL):
                     assert False, "LikeButtonError: Cannot find XPATH."
 
                 if not is_liked:
-                    self.video_ids.append(link[32:])
                     self.number_of_to_be_liked_streams += 1
                     ActionChains(self.driver).move_to_element(like_button).click(like_button).perform()
                     print(f"Video from {name} is liked.")
 
             self.stream_data['No. of to-be-liked streams'] = self.number_of_to_be_liked_streams
-            self.stream_data['Streams liked'] = ', '.join(self.video_ids)
+            self.stream_data['Streams liked'] = ','.join(self.currently_streaming.values())
 
     def get_end_time(self):
         self.time_ended = time.strftime("%H:%M:%S", time.localtime())
@@ -219,16 +200,21 @@ class StreamLiker(YSL):
         my_cursor.execute(query + "VALUES(%s,%s,%s,%s,%s,%s,%s,%s)", (tel, nas, nls, ts, te, d, ver, cst))
         db.commit()
 
-    def start_liking_with_data(self, user, host, passwd, db, table_name, my_dir, path, options = None):
+    def start_liking_with_data(self, user, host, passwd, db, table_name, my_dir, path, profile, options=None):
         self.get_start_time()
         self.is_streaming()
-        self.config_driver(path, options)
+        self.config_driver(path, profile, options)
         self.like_videos()
         self.get_end_time()
         self.append_data_on_file(my_dir)
         self.append_data_on_db(user, host, passwd, db, table_name)
 
-    def config_driver(self, path, args=None):
+    def config_driver(self, path, firefox_profile, args=None):
+        if self.number_of_active_streams == 0:
+            print("There are no active streams as of the moment.")
+            return
+
+        self.like = True
         try:
             for arg in args:
                 self.options.add_argument(arg)
@@ -236,7 +222,7 @@ class StreamLiker(YSL):
             print("No args supplied for driver options.")
 
         profile = webdriver.FirefoxProfile(
-            'C:/Users/ISAAC/AppData/Roaming/Mozilla/Firefox/Profiles/fwnbfuph.default-release'
+            firefox_profile
         )
         profile.set_preference("dom.webdriver.enabled", False)
         profile.set_preference('useAutomationExtension', False)
